@@ -24,6 +24,7 @@ import (
 
 	imgextract "github.com/openshift/oc/pkg/cli/image/extract"
 	"github.com/openshift/oc/pkg/cli/image/imagesource"
+	imagemanifest "github.com/openshift/oc/pkg/cli/image/manifest"
 	imgmirror "github.com/openshift/oc/pkg/cli/image/mirror"
 )
 
@@ -43,6 +44,17 @@ var (
 			A mapping.txt file is also created that is compatible with "oc image mirror". This may be used to further
 			customize the mirroring configuration, but should not be needed in normal circumstances.
 		`)
+	mirrorExample = templates.Examples(`
+# Mirror an operator-registry image and its contents to a registry
+%[1]s quay.io/my/image:latest myregistry.com
+
+# Configure a cluster to use a mirrored registry
+oc apply -f manifests/imageContentSourcePolicy.yaml
+
+# Edit the mirroring mappings and mirror with "oc image mirror" manually
+%[1]s --manifests-only quay.io/my/image:latest myregistry.com
+oc image mirror -f manifests/mapping.txt
+`)
 )
 
 type MirrorCatalogOptions struct {
@@ -56,6 +68,10 @@ type MirrorCatalogOptions struct {
 	FromFileDir string
 	FileDir     string
 
+	SecurityOptions imagemanifest.SecurityOptions
+	FilterOptions   imagemanifest.FilterOptions
+	ParallelOptions imagemanifest.ParallelOptions
+
 	SourceRef imagesource.TypedImageReference
 	Dest      string
 }
@@ -64,6 +80,7 @@ func NewMirrorCatalogOptions(streams genericclioptions.IOStreams) *MirrorCatalog
 	return &MirrorCatalogOptions{
 		IOStreams:                 streams,
 		IndexImageMirrorerOptions: mirror.DefaultImageIndexMirrorerOptions(),
+		ParallelOptions:           imagemanifest.ParallelOptions{MaxPerRegistry: 4},
 	}
 }
 
@@ -71,9 +88,10 @@ func NewMirrorCatalog(streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewMirrorCatalogOptions(streams)
 
 	cmd := &cobra.Command{
-		Use:   "mirror",
-		Short: "mirror an operator-registry catalog",
-		Long:  mirrorLong,
+		Use:     "mirror SRC DEST",
+		Short:   "mirror an operator-registry catalog",
+		Long:    mirrorLong,
+		Example: fmt.Sprintf(mirrorExample, "oc adm catalog mirror"),
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(cmd, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -82,6 +100,10 @@ func NewMirrorCatalog(streams genericclioptions.IOStreams) *cobra.Command {
 	}
 	flags := cmd.Flags()
 
+	o.SecurityOptions.Bind(flags)
+	o.FilterOptions.Bind(flags)
+	o.ParallelOptions.Bind(flags)
+
 	flags.StringVar(&o.ManifestDir, "to-manifests", "", "Local path to store manifests.")
 	flags.StringVar(&o.DatabasePath, "path", "", "Specify an in-container to local path mapping for the database.")
 	flags.BoolVar(&o.DryRun, "dry-run", o.DryRun, "Print the actions that would be taken and exit without writing to the destinations.")
@@ -137,6 +159,7 @@ func (o *MirrorCatalogOptions) Complete(cmd *cobra.Command, args []string) error
 				klog.Warningf("couldn't parse %s, skipping mirror: %v", from, err)
 				continue
 			}
+
 			// remove destination digest if present
 			toRef, err := imagesource.ParseReference(to)
 			if err != nil {
@@ -156,6 +179,10 @@ func (o *MirrorCatalogOptions) Complete(cmd *cobra.Command, args []string) error
 			a := imgmirror.NewMirrorImageOptions(o.IOStreams)
 			a.SkipMissing = true
 			a.DryRun = o.DryRun
+			a.SecurityOptions = o.SecurityOptions
+			a.FilterOptions = o.FilterOptions
+			a.ParallelOptions = o.ParallelOptions
+			a.ForceManifestList = true
 			a.Mappings = []imgmirror.Mapping{{
 				Source:      fromRef[0],
 				Destination: toRef,
@@ -180,6 +207,9 @@ func (o *MirrorCatalogOptions) Complete(cmd *cobra.Command, args []string) error
 
 	var extractor mirror.DatabaseExtractorFunc = func(from string) (string, error) {
 		e := imgextract.NewOptions(o.IOStreams)
+		e.SecurityOptions = o.SecurityOptions
+		e.FilterOptions = o.FilterOptions
+		e.ParallelOptions = o.ParallelOptions
 		e.FileDir = o.FileDir
 		if len(o.FromFileDir) > 0 {
 			e.FileDir = o.FromFileDir
